.. PyRgrow documentation master file, created by
   sphinx-quickstart on Fri Oct  9 18:01:25 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

PyRgrow documentation
=====================

.. toctree::
   :maxdepth: 3
   :caption: Contents:

.. automodule:: rgrow         


Models
------

.. autoclass:: StaticKTAM
   :members:

.. autoclass:: StaticKTAMPeriodic
   :members:

States
------

.. autoclass:: StateKTAM
   :members:

FFS Functions
-------------

.. autofunction:: ffs_run

.. autofunction:: ffs_run_final

.. autofunction:: ffs_run_full

.. autofunction:: ffs_run_final_p


Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
